@@ -5,19 +5,42 @@ package App::Pinto::Admin::Command::list;
 use strict;
 use warnings;
 
+use Readonly;
+use List::MoreUtils qw(none);
+
 #-----------------------------------------------------------------------------
 
 use base 'App::Pinto::Admin::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.016'; # VERSION
+our $VERSION = '0.017'; # VERSION
+
+#------------------------------------------------------------------------------
+
+Readonly my @LIST_TYPES => qw(local foreign conflicts all);
+Readonly my $LIST_TYPES_STRING => join ' | ', sort @LIST_TYPES;
+Readonly my $DEFAULT_LIST_TYPE => 'all';
+
+#------------------------------------------------------------------------------
+
+sub opt_spec {
+
+    return (
+        [ 'type=s'  => "One of: ( $LIST_TYPES_STRING )"],
+    );
+}
 
 #------------------------------------------------------------------------------
 
 sub validate_args {
     my ($self, $opts, $args) = @_;
+
     $self->usage_error('Arguments are not allowed') if @{ $args };
+
+    $opts->{type} ||= $DEFAULT_LIST_TYPE;
+    $self->usage_error('Invalid type') if none { $opts->{type} eq $_ } @LIST_TYPES;
+
     return 1;
 }
 
@@ -25,8 +48,13 @@ sub validate_args {
 
 sub execute {
     my ($self, $opts, $args) = @_;
-    $self->pinto( $opts )->list();
-    return 0;
+
+    $self->pinto->new_action_batch( %{$opts} );
+    my $list_class = 'List::' . ucfirst $opts->{type};
+    $self->pinto->add_action($list_class, %{$opts});
+    my $result = $self->pinto->run_actions();
+    return $result->is_success() ? 0 : 1;
+
 }
 
 #------------------------------------------------------------------------------
@@ -45,7 +73,7 @@ App::Pinto::Admin::Command::list - list the contents of the repository
 
 =head1 VERSION
 
-version 0.016
+version 0.017
 
 =head1 AUTHOR
 
