@@ -3,7 +3,6 @@ package Pinto::Action;
 # ABSTRACT: Base class for Actions
 
 use Moose;
-use Moose::Autobox;
 
 use Carp;
 
@@ -11,7 +10,7 @@ use namespace::autoclean;
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.016'; # VERSION
+our $VERSION = '0.017'; # VERSION
 
 #------------------------------------------------------------------------------
 # Attributes
@@ -31,8 +30,21 @@ has store => (
 has messages => (
     is         => 'ro',
     isa        => 'ArrayRef[Str]',
+    traits     => [ 'Array' ],
     default    => sub{ [] },
     init_arg   => undef,
+    handles    => {add_message => 'push'},
+    auto_deref => 1,
+);
+
+has exceptions => (
+    is         => 'ro',
+    isa        => 'ArrayRef[Pinto::Exception]',
+    traits     => [ 'Array' ],
+    default    => sub{ [] },
+    init_arg   => undef,
+    handles    => {add_exception => 'push'},
+    auto_deref => 1,
 );
 
 #------------------------------------------------------------------------------
@@ -46,22 +58,11 @@ with qw( Pinto::Role::Configurable
 
 sub execute {
     my ($self) = @_;
-
     croak 'This is an absract method';
 }
 
 #------------------------------------------------------------------------------
 
-sub add_message {
-    my ($self, @messages) = @_;
-
-    $self->messages()->push( @messages );
-
-    return $self;
-}
-
-#------------------------------------------------------------------------------
-
 __PACKAGE__->meta->make_immutable();
 
 #------------------------------------------------------------------------------
@@ -80,7 +81,7 @@ Pinto::Action - Base class for Actions
 
 =head1 VERSION
 
-version 0.016
+version 0.017
 
 =head1 AUTHOR
 
