@@ -4,7 +4,6 @@ package Pinto::Action::Create;
 
 use Moose;
 
-use Carp;
 use Path::Class;
 
 extends 'Pinto::Action';
@@ -13,23 +12,35 @@ use namespace::autoclean;
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.016'; # VERSION
+our $VERSION = '0.017'; # VERSION
+
+#------------------------------------------------------------------------------
+
+with qw(Pinto::Role::PathMaker);
 
 #------------------------------------------------------------------------------
 
 sub execute {
     my ($self) = @_;
 
-    # This is a terrible hack.  We are relying on Pinto::Index
-    # to create the files for us.
-
+    # Write indexes
     my $master_index_file = $self->idxmgr->master_index->write->file();
     my $local_index_file  = $self->idxmgr->local_index->write->file();
 
+    # Create config dir
+    my $config_dir = $self->config->repos->subdir('config');
+    $self->mkpath($config_dir);
+
+    # Write config file
+    my $config_file = $config_dir->file('pinto.ini');
+    $self->config->write_config_file( file => $config_file );
+
     $self->store->add( file => $master_index_file );
     $self->store->add( file => $local_index_file );
+    $self->store->add( file => $config_file );
 
     $self->add_message('Created a new Pinto repository');
+
     return 1;
 }
 
@@ -53,7 +64,7 @@ Pinto::Action::Create - An action to create a new repository
 
 =head1 VERSION
 
-version 0.016
+version 0.017
 
 =head1 AUTHOR
 
