@@ -4,6 +4,8 @@ package Pinto::Action::Mirror;
 
 use Moose;
 
+use MooseX::Types::Moose qw(Bool);
+
 use URI;
 use Try::Tiny;
 
@@ -15,7 +17,16 @@ extends 'Pinto::Action';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.016'; # VERSION
+our $VERSION = '0.017'; # VERSION
+
+#------------------------------------------------------------------------------
+# Moose Attributes
+
+has force => (
+    is      => 'ro',
+    isa     => Bool,
+    default => 0,
+);
 
 #------------------------------------------------------------------------------
 # Moose Roles
@@ -28,13 +39,18 @@ sub execute {
     my ($self) = @_;
 
     my $idxmgr  = $self->idxmgr();
-    my $idx_changes = $idxmgr->update_mirror_index();
-    return 0 if not $idx_changes and not $self->config->force();
+    my $idx_changes = $idxmgr->update_mirror_index( force => $self->force() );
+    return 0 if not $idx_changes and not $self->force();
 
     my $dist_changes = 0;
     for my $dist ( $idxmgr->dists_to_mirror() ) {
-        try   { $dist_changes += $self->_do_mirror($dist) }
-        catch { $self->logger->whine("Download of $dist failed: $_") };
+        try   {
+            $dist_changes += $self->_do_mirror($dist);
+        }
+        catch {
+            $self->add_exception($_);
+            $self->logger->whine("Download of $dist failed: $_");
+        };
     }
 
     return 0 if not ($idx_changes + $dist_changes);
@@ -50,19 +66,19 @@ sub execute {
 sub _do_mirror {
     my ($self, $dist) = @_;
 
-    my $local   = $self->config->local();
+    my $repos   = $self->config->repos();
     my $source  = $self->config->source();
     my $cleanup = !$self->config->nocleanup();
 
     my $url = $dist->url($source);
-    my $destination = $dist->path($local);
+    my $destination = $dist->path($repos);
     return 0 if -e $destination;
 
-    $self->mirror(url => $url, to => $destination) or return 0;
+    $self->fetch(url => $url, to => $destination) or return 0;
     $self->store->add(file => $destination);
 
     my @removed = $self->idxmgr->add_mirrored_distribution(dist => $dist);
-    $cleanup && $self->store->remove(file => $_->path($local)) for @removed;
+    $cleanup && $self->store->remove(file => $_->path($repos)) for @removed;
 
     return 1;
 }
@@ -87,7 +103,7 @@ Pinto::Action::Mirror - An action to mirror a remote repository into your local
 
 =head1 VERSION
 
-version 0.016
+version 0.017
 
 =head1 AUTHOR
 
