@@ -6,6 +6,7 @@ use Moose;
 use Moose::Autobox;
 
 use Pinto::Util;
+use Pinto::Types 0.017 qw(IO);
 
 extends 'Pinto::Action';
 
@@ -13,23 +14,29 @@ use namespace::autoclean;
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.016'; # VERSION
+our $VERSION = '0.017'; # VERSION
+
+#------------------------------------------------------------------------------
+
+has out => (
+    is       => 'ro',
+    isa      => IO,
+    coerce   => 1,
+    default  => sub { [fileno(STDOUT), '>'] },
+);
 
 #------------------------------------------------------------------------------
 
 sub execute {
     my ($self) = @_;
 
-    my $local = $self->config()->local();
-    my $dists = $self->idxmgr->master_index->distributions->values();
-    my $sorter = sub {$_[0]->location() cmp $_[1]->location};
-
-    # TODO: accept an alternative filehandle for output.
-    # TODO: force log_level to quiet when running this action.
+    my $repos   = $self->config()->repos();
+    my $dists   = $self->idxmgr->master_index->distributions->values();
+    my $sorter  = sub {$_[0]->location() cmp $_[1]->location};
 
     for my $dist ( $dists->sort( $sorter )->flatten() ) {
-        my $file = $dist->path($local);
-        print "Missing distribution $file\n" if not -e $file;
+        my $file = $dist->path($repos);
+        print { $self->out } "Missing distribution $file\n" if not -e $file;
     }
 
     return 0;
@@ -55,7 +62,7 @@ Pinto::Action::Verify - An action to verify all files are present in the reposit
 
 =head1 VERSION
 
-version 0.016
+version 0.017
 
 =head1 AUTHOR
 
