@@ -1,173 +1,107 @@
 package Pinto::Config;
 
-# ABSTRACT: User configuration for Pinto
+# ABSTRACT: Internal configuration for a Pinto repository
 
 use Moose;
+
 use MooseX::Configuration;
-use MooseX::LazyRequire;
 
 use MooseX::Types::Moose qw(Str Bool Int);
-use Pinto::Types qw(AuthorID URI Dir);
-
-use Carp;
-use English qw(-no_match_vars);
+use Pinto::Types 0.017 qw(URI Dir);
 
 use namespace::autoclean;
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.012'; # VERSION
+our $VERSION = '0.017'; # VERSION
 
 #------------------------------------------------------------------------------
 # Moose attributes
 
-has 'local'   => (
+has repos   => (
     is        => 'ro',
     isa       => Dir,
-    key       => 'local',
     required  => 1,
     coerce    => 1,
 );
 
 
-has 'source'  => (
+has source  => (
     is        => 'ro',
     isa       => URI,
     key       => 'source',
     default   => 'http://cpan.perl.org',
     coerce    => 1,
+    documentation => 'URL of a CPAN mirror (or Pinto repository) where foreign dists will be pulled from',
 );
 
 
-has 'author'  => (
-    is        => 'ro',
-    isa       => AuthorID,
-    key       => 'author',
-    coerce    => 1,
-    lazy      => 1,
-    builder   => '_build_author',
-);
-
-
-has 'nocleanup' => (
+has nocleanup => (
     is        => 'ro',
     isa       => Bool,
     key       => 'nocleanup',
     default   => 0,
+    documentation => 'If true, then Pinto will not delete older distributions when newer versions are added',
 );
 
 
-has 'noinit' => (
+has noclobber => (
     is        => 'ro',
     isa       => Bool,
-    key       => 'noinit',
+    key       => 'noclobber',
     default   => 0,
+    documentation => 'If true, then Pinto will not clobber existing packages when adding new ones',
 );
 
 
-has 'force'    => (
-    is        => 'ro',
-    isa       => Bool,
-    key       => 'force',
-    default   => 0,
+has noinit   => (
+    is       => 'ro',
+    isa      => Bool,
+    key      => 'noinit',
+    default  => 0,
+    documentation => 'If true, then Pinto will not update/pull the repository from VCS before each action',
 );
 
 
-has 'store' => (
+has store => (
     is        => 'ro',
     isa       => Str,
     key       => 'store',
     default   => 'Pinto::Store',
+    documentation => 'Name of the class that will handle storage of your repository',
 );
 
 
-has 'nocommit' => (
-    is       => 'ro',
-    isa      => Bool,
-    key      => 'nocommit',
-    default  => 0,
+has svn_trunk => (
+    is        => 'ro',
+    isa       => Str,
+    key       => 'trunk',
+    section   => 'Pinto::Store::VCS::Svn',
 );
 
 
-has 'notag' => (
-    is      => 'ro',
-    isa     => 'Bool',
-    key     => 'notag',
-    default => 0,
-);
-
-
-has 'quiet'  => (
-    is       => 'ro',
-    isa      => Bool,
-    key      => 'quiet',
-    default  => 0,
-);
-
-
-has 'verbose' => (
-    is          => 'ro',
-    isa         => Int,
-    key         => 'verbose',
-    default     => 0,
-);
-
-
-has 'svn_trunk' => (
-    is            => 'ro',
-    isa           => Str,
-    key           => 'trunk',
-    section       => 'Pinto::Store::Svn',
-    lazy_required => 1,
-);
-
-
-has 'svn_tag' => (
-    is          => 'ro',
-    isa         => Str,
-    key         => 'tag',
-    section     => 'Pinto::Store::Svn',
-    default     => '',
+has svn_tag => (
+    is        => 'ro',
+    isa       => Str,
+    key       => 'tag',
+    section   => 'Pinto::Store::VCS::Svn',
 );
 
 #------------------------------------------------------------------------------
 # Builders
 
 sub _build_config_file {
+    my ($self) = @_;
 
-    my $PINTO_ENV_VAR = $ENV{PERL_PINTO};
-    return $PINTO_ENV_VAR if $PINTO_ENV_VAR and -e $PINTO_ENV_VAR;
+    my $repos = $self->repos();
 
-    require File::HomeDir;
-    my $home = File::HomeDir->my_home()
-        or croak 'Unable to determine your home directory';
+    my $config_file = Path::Class::file($repos, qw(config pinto.ini) );
 
-    require Path::Class;
-    my $file = Path::Class::file($home, qw(.pinto config.ini));
-
-    return -e $file ? $file : ();
+    return -e $config_file ? $config_file : ();
 }
 
 #------------------------------------------------------------------------------
 
-sub _build_author {
-
-    # Look at typical environment variables
-    for my $var ( qw(USERNAME USER LOGNAME) ) {
-        return uc $ENV{$var} if $ENV{$var};
-    }
-
-    # Try using pwent.  Probably only works on *nix
-    if (my $name = getpwuid($REAL_USER_ID)) {
-        return uc $name;
-    }
-
-    # Otherwise, we are hosed!
-    croak 'Unable to determine your user name';
-
-}
-#------------------------------------------------------------------------------
-
 __PACKAGE__->meta->make_immutable();
 
 #------------------------------------------------------------------------------
@@ -182,11 +116,11 @@ __PACKAGE__->meta->make_immutable();
 
 =head1 NAME
 
-Pinto::Config - User configuration for Pinto
+Pinto::Config - Internal configuration for a Pinto repository
 
 =head1 VERSION
 
-version 0.012
+version 0.017
 
 =head1 DESCRIPTION
 
