@@ -4,15 +4,17 @@ package Pinto::Role::PathMaker;
 
 use Moose::Role;
 
-use Carp;
 use Path::Class;
 use English qw(-no_match_vars);
 
+use Pinto::Exception::IO qw(throw_io);
+use Pinto::Exception::Args qw(throw_args);
+
 use namespace::autoclean;
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.016'; # VERSION
+our $VERSION = '0.017'; # VERSION
 
 #------------------------------------------------------------------------------
 # Required attributes
@@ -27,15 +29,15 @@ sub mkpath {
 
     $path = dir($path) if not eval {$path->isa('Path::Class')};
 
-    croak "$path is not a Path::Class::Dir" if not $path->is_dir();
-    croak "$path is an existing file" if -f $path;
+    throw_args "$path is not a Path::Class::Dir" if not $path->is_dir();
+    throw_args "$path is an existing file" if -f $path;
 
     return 0 if -e $path;
 
     $self->logger->debug("Making directory $path");
 
     eval { $path->mkpath(); 1}
-        or croak "Failed to make directory $path: $EVAL_ERROR";
+        or throw_io "Failed to make directory $path: $EVAL_ERROR";
 
     return 1;
 }
@@ -56,15 +58,15 @@ Pinto::Role::PathMaker - Something that makes directory paths
 
 =head1 VERSION
 
-version 0.016
+version 0.017
 
 =head1 METHODS
 
 =head2 mkpath( $path )
 
 Creates a directory at the specified path, including any intervening
-directories.  Croaks on failure.  Returns true if a path was actually
-made.  If the path already existed, returns false.
+directories.  Throws an exception on failure.  Returns true if a path
+was actually made.  If the path already existed, returns false.
 
 =head1 AUTHOR
 
