@@ -11,7 +11,7 @@ use namespace::autoclean;
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.025_004'; # VERSION
+our $VERSION = '0.017'; # VERSION
 
 #------------------------------------------------------------------------------
 # Moose attributes
@@ -46,18 +46,6 @@ has _mods => (
 #------------------------------------------------------------------------------
 # Methods
 
-#------------------------------------------------------------------------------
-
-override commit => sub {
-    my ($self);
-
-    $self->mark_path_as_modified( $self->config->pinto_dir() );
-
-    return $self;
-};
-
-#------------------------------------------------------------------------------
-
 sub mark_path_as_added {
     my ($self, $path) = @_;
 
@@ -129,7 +117,7 @@ Pinto::Store::VCS - Base class for VCS-backed Stores
 
 =head1 VERSION
 
-version 0.025_004
+version 0.017
 
 =head1 AUTHOR
 
