@@ -10,7 +10,14 @@ extends 'Pinto::Store::VCS';
 
 #-------------------------------------------------------------------------------
 
-our $VERSION = '0.025_004'; # VERSION
+our $VERSION = '0.017'; # VERSION
+
+#-------------------------------------------------------------------------------
+
+override is_initialized => sub {
+    croak __PACKAGE__ . ' is not implemented yet';
+    # -e .git
+};
 
 #-------------------------------------------------------------------------------
 
@@ -21,28 +28,21 @@ override initialize => sub {
 
 #-------------------------------------------------------------------------------
 
-override commit => sub {
+override finalize => sub {
     croak __PACKAGE__ . 'is not implemented yet';
     # git commit and push
 };
 
 #-------------------------------------------------------------------------------
 
-override tag => sub {
-    croak __PACKAGE__ . 'is not implemented yet';
-    # git tag
-};
-
-#-------------------------------------------------------------------------------
-
-override add_file => sub {
+override add => sub {
     croak __PACKAGE__ . 'is not implemented yet';
     # git add
 };
 
 #-------------------------------------------------------------------------------
 
-override remove_file => sub {
+override remove => sub {
     croak __PACKAGE__ . 'is not implemented yet';
     # git rm
 };
@@ -62,7 +62,7 @@ Pinto::Store::VCS::Git - Store your Pinto repository with Git
 
 =head1 VERSION
 
-version 0.025_004
+version 0.017
 
 =head1 DESCRIPTION
 
